@@ -1,7 +1,8 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 # encoding: utf-8
 """
-Copyright 2013 iACT, Universite de Montreal, Jean Piche, Olivier Belanger, Jean-Michel Dumas
+Copyright 2013 iACT, Universite de Montreal, 
+Jean Piche, Olivier Belanger, Jean-Michel Dumas
 
 This file is part of Cecilia 5.
 
@@ -18,48 +19,45 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Cecilia 5.  If not, see <http://www.gnu.org/licenses/>.
 """
-
-import wx
 import os, sys, random
+import wx
 from Resources.constants import *
 from Resources import audio, CeciliaMainFrame
-import Resources.CeciliaLib as CeciliaLib
 from Resources.splash import CeciliaSplashScreen
+import Resources.CeciliaLib as CeciliaLib
 
-def GetRoundBitmap( w, h, r ):
-    maskColor = wx.Colour(0,0,0)
-    shownColor = wx.Colour(5,5,5)
-    b = wx.EmptyBitmap(w,h)
-    dc = wx.MemoryDC(b)
-    dc.SetBrush(wx.Brush(maskColor))
-    dc.DrawRectangle(0,0,w,h)
-    dc.SetBrush(wx.Brush(shownColor))
-    dc.SetPen(wx.Pen(shownColor))
-    dc.DrawRoundedRectangle(0,0,w,h,r)
-    dc.SelectObject(wx.NullBitmap)
-    b.SetMaskColour(maskColor)
-    return b
-
-def GetRoundShape( w, h, r ):
-    return wx.RegionFromBitmap(GetRoundBitmap(w,h,r))
 
 class CeciliaApp(wx.App):
     def __init__(self, *args, **kwargs):
         wx.App.__init__(self, *args, **kwargs)
 
-    def MacOpenFile(self, filename):
-        CeciliaLib.getVar("mainFrame").onOpen(filename)
+    def MacOpenFiles(self, filenames):
+        if type(filenames) == list:
+            filenames = filenames[0]
+        if CeciliaLib.getVar("mainFrame") is not None:
+            CeciliaLib.getVar("mainFrame").onOpen(filenames)
+
+    def MacReopenApp(self):
+        try:
+            CeciliaLib.getVar("mainFrame").Raise()
+        except:
+            pass
+
 
 def onStart():
     ceciliaMainFrame = CeciliaMainFrame.CeciliaMainFrame(None, -1)
     CeciliaLib.setVar("mainFrame", ceciliaMainFrame)
+    app.SetTopWindow(ceciliaMainFrame)
 
-    file = None
-    if len(sys.argv) >= 2:
+    file = ""
+    if len(sys.argv) > 1:
         file = sys.argv[1]
 
-    if file:
+    if os.path.isfile(file):
         ceciliaMainFrame.onOpen(file)
+    elif CeciliaLib.getVar("lastCeciliaFile") != '' and os.path.isfile(CeciliaLib.getVar("lastCeciliaFile")):
+        ceciliaMainFrame.onOpen(CeciliaLib.getVar("lastCeciliaFile"),
+                                MODULES_PATH in CeciliaLib.getVar("lastCeciliaFile"))
     else:
         categories = [folder for folder in os.listdir(MODULES_PATH) if not folder.startswith(".")]
         category = random.choice(categories)
@@ -67,14 +65,13 @@ def onStart():
         file = random.choice(files)
         ceciliaMainFrame.onOpen(os.path.join(MODULES_PATH, category, file), True)
 
+
 if __name__ == '__main__':
-    reload(sys)
-    sys.setdefaultencoding('utf-8')
 
     if not os.path.isdir(TMP_PATH):
         os.mkdir(TMP_PATH)
-    if not os.path.isfile(os.path.join(TMP_PATH,'.recent.txt')):
-        f = open(os.path.join(TMP_PATH,'.recent.txt'), "w")
+    if not os.path.isfile(os.path.join(TMP_PATH, '.recent.txt')):
+        f = open(os.path.join(TMP_PATH, '.recent.txt'), "w")
         f.close()
     if not os.path.isdir(AUTOMATION_SAVE_PATH):
         os.mkdir(AUTOMATION_SAVE_PATH)
@@ -88,13 +85,15 @@ if __name__ == '__main__':
         pass
 
     app = CeciliaApp(redirect=False)
-    wx.SetDefaultPyEncoding('utf-8')
+    wx.Log.SetLogLevel(0)
+    if sys.version_info[0] < 3:
+        wx.SetDefaultPyEncoding('utf-8')
 
     try:
         display = wx.Display()
         numDisp = display.GetCount()
         if CeciliaLib.getVar("DEBUG"):
-            print 'Numbers of displays:', numDisp
+            print('Numbers of displays:', numDisp)
         displays = []
         displayOffset = []
         displaySize = []
@@ -103,9 +102,10 @@ if __name__ == '__main__':
             offset = displays[i].GetGeometry()[:2]
             size = displays[i].GetGeometry()[2:]
             if CeciliaLib.getVar("DEBUG"):
-                print 'display %d:' % i
-                print '    pos =', offset
-                print '    size =', size
+                print('display %d:' % i)
+                print('    pos =', offset)
+                print('    size =', size)
+                print()
             displayOffset.append(offset)
             displaySize.append(size)
     except:
@@ -117,6 +117,6 @@ if __name__ == '__main__':
     CeciliaLib.setVar("displayOffset", displayOffset)
     CeciliaLib.setVar("displaySize", displaySize)
 
-    sp = CeciliaSplashScreen(None, img=SPLASH_FILE_PATH, callback=onStart)
+    sp = CeciliaSplashScreen(None, img=CeciliaLib.ensureNFD(SPLASH_FILE_PATH), callback=onStart)
 
     app.MainLoop()
