@@ -18,15 +18,19 @@ You should have received a copy of the GNU General Public License
 along with Cecilia 5.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import os, sys, wx, time, math, copy, codecs, pdb
-from types import UnicodeType, IntType
+import os, sys, wx, time, math, copy, codecs
 import pprint as pp
-from constants import *
-import Variables as vars
-from API_interface import *
 import unicodedata
 from subprocess import Popen
-from pyolib._wxwidgets import SpectrumDisplay
+from .constants import *
+from .API_interface import *
+import Resources.Variables as vars
+import wx.lib.agw.supertooltip as STT
+
+if sys.version_info[0] < 3:
+    unicode_t = unicode
+else:
+    unicode_t = str
 
 def buildFileTree():
     root = MODULES_PATH
@@ -50,12 +54,12 @@ def getVar(var, unicode=False):
     else:
         return vars.CeciliaVar[var]
 
-def setJackParams(client = None, inPortName = None, outPortName = None):
-    if not client==None:
+def setJackParams(client=None, inPortName=None, outPortName=None):
+    if client is not None:
         vars.CeciliaVar['jack']['client'] = client
-    if not inPortName==None:
+    if inPortName is not None:
         vars.CeciliaVar['jack']['inPortName'] = inPortName
-    if not outPortName==None:
+    if outPortName is not None:
         vars.CeciliaVar['jack']['outPortName'] = outPortName
 
 def setPlugins(x, pos):
@@ -69,14 +73,14 @@ def writeVarToDisk():
 
 def chooseColour(i, numlines):
     def clip(x):
-        val = int(x*255)
+        val = int(x * 255)
         if val < 0: val = 0
         elif val > 255: val = 255
         else: val = val
         return val
 
     def colour(i, numlines, sat, bright):
-        hue = (i / float(numlines)) * 315
+        hue = (i / numlines) * 315
         segment = math.floor(hue / 60) % 6
         fraction = hue / 60 - segment
         t1 = bright * (1 - sat)
@@ -94,7 +98,7 @@ def chooseColour(i, numlines):
             r, g, b = t3, t1, bright
         elif segment == 5:
             r, g, b = bright, t1, t2
-        return wx.Colour(clip(r),clip(g),clip(b))
+        return wx.Colour(clip(r), clip(g), clip(b))
 
     lineColour = colour(i, numlines, 1, 1)
     midColour = colour(i, numlines, .5, .5)
@@ -105,7 +109,7 @@ def chooseColour(i, numlines):
 
 def chooseColourFromName(name):
     def clip(x):
-        val = int(x*255)
+        val = int(x * 255)
         if val < 0: val = 0
         elif val > 255: val = 255
         else: val = val
@@ -133,22 +137,66 @@ def chooseColourFromName(name):
             r, g, b = t3, t1, bright
         elif segment == 5:
             r, g, b = bright, t1, t2
-        return wx.Colour(clip(r),clip(g),clip(b))
+        return wx.Colour(clip(r), clip(g), clip(b))
 
-    lineColour = colour(name)    
+    lineColour = colour(name)
     midColour = colour(name)
     knobColour = colour(name)
     sliderColour = colour(name)
 
     return [lineColour, midColour, knobColour, sliderColour]
 
+### Tooltips ###
+class CECTooltip(STT.SuperToolTip):
+    def __init__(self, tip):
+        STT.SuperToolTip.__init__(self, tip)
+        self.SetStartDelay(1.5)
+        if getVar("useTooltips"):
+            self.EnableTip(True)
+        else:
+            self.EnableTip(False)
+        self.ApplyStyle("Gray")
+
+    def OnMouseEvents(self, evt):
+        if evt.ButtonDown() or evt.ButtonDClick():
+            self.DoHideNow()
+        evt.Skip()
+
+    def update(self):
+        if getVar("useTooltips"):
+            self.EnableTip(True)
+        else:
+            self.EnableTip(False)
+
+def setToolTip(obj, tip):
+    if "\n" in tip:
+        pos = tip.find("\n")
+        header = tip[:pos]
+        body = tip[pos+1:]
+    else:
+        header = "Documentation"
+        body = tip
+    tooltip = CECTooltip(body)
+    tooltip.SetHeader(header)
+    tooltip.SetTarget(obj)
+    tooltip.SetDrawHeaderLine(True)
+    getVar("tooltips").append(tooltip)
+    obj.Bind(wx.EVT_MOUSE_EVENTS, tooltip.OnMouseEvents)
+
+def updateTooltips():
+    for tooltip in getVar("tooltips"):
+        tooltip.update()
+
 ###### Start / Stop / Drivers ######
 def startCeciliaSound(timer=True, rec=False):
     # Check if soundfile is loaded
     for key in getVar("userInputs").keys():
+        if 'mode' not in getVar("userInputs")[key]:
+            getVar("userInputs")[key]['mode'] = 0
         if getVar("userInputs")[key]['mode'] == 0:
             if not os.path.isfile(getVar("userInputs")[key]['path']):
-                showErrorDialog('No input sound file!', 'In/Out panel, "%s" has no input sound file, please load one...' % getControlPanel().getCfileinFromName(key).label)
+                showErrorDialog('No input sound file!',
+                                'In/Out panel, "%s" has no input sound file, please load one...' % getControlPanel().getCfileinFromName(key).label)
                 ret = getControlPanel().getCfileinFromName(key).onLoadFile()
                 if not ret:
                     resetControls()
@@ -156,36 +204,36 @@ def startCeciliaSound(timer=True, rec=False):
                     wx.CallAfter(getVar("grapher").toolbar.loadingMsg.Refresh)
                     return
     getControlPanel().resetMeter()
-    if getVar('spectrumFrame') != None:
+    getVar("audioServer").shutdown()
+    getVar("audioServer").reinit()
+    getVar("audioServer").boot()
+    if getVar("currentModuleRef") is not None:
+        if not getVar("audioServer").loadModule(getVar("currentModuleRef")):
+            return
+    else:
+        showErrorDialog("Wow...!", "No module to load.")
+        return
+    getVar("grapher").toolbar.convertSlider.Hide()
+    getVar("presetPanel").presetChoice.setEnable(False)
+    getControlPanel().durationSlider.Disable()
+    getVar("audioServer").start(timer=timer, rec=rec)
+    if getVar('showSpectrum'):
+        getVar('mainFrame').openSpectrumWindow()
+    getVar("grapher").toolbar.loadingMsg.SetForegroundColour(TITLE_BACK_COLOUR)
+    wx.CallAfter(getVar("grapher").toolbar.loadingMsg.Refresh)
+
+def stopCeciliaSound():
+    if getVar('spectrumFrame') is not None:
         try:
-            getVar('spectrumFrame')._destroy(None)
+            getVar('spectrumFrame').onClose()
         except:
             getVar('interface').menubar.spectrumSwitch(False)
             setVar('showSpectrum', 0)
         finally:
             setVar('spectrumFrame', None)
-    getVar("audioServer").shutdown()
-    getVar("audioServer").reinit()
-    getVar("audioServer").boot()
-    if getVar("currentModuleRef") != None:
-        getVar("audioServer").loadModule(getVar("currentModuleRef"))
-    else:
-        showErrorDialog("Wow...!", "No module to load.")
-    getVar("grapher").toolbar.convertSlider.Hide()
-    getVar("presetPanel").presetChoice.setEnable(False)
-    getVar("audioServer").start(timer=timer, rec=rec)
-    if getVar('showSpectrum'):
-        f = SpectrumDisplay(None, getVar("audioServer").spectrum)
-        getVar("audioServer").spectrum._setViewFrame(f)
-        setVar('spectrumFrame', f)
-        f.Show()
-    getVar("grapher").toolbar.loadingMsg.SetForegroundColour(TITLE_BACK_COLOUR)
-    wx.CallAfter(getVar("grapher").toolbar.loadingMsg.Refresh)
-
-def stopCeciliaSound():
     if getVar("audioServer").isAudioServerRunning():
         getVar("audioServer").stop()
-        if getVar("currentModule") != None:
+        if getVar("currentModule") is not None:
             getVar("audioServer").checkForAutomation()
             getVar("currentModule")._checkForAutomation()
             getVar("grapher").checkForAutomation()
@@ -193,19 +241,19 @@ def stopCeciliaSound():
     resetControls()
 
 def resetControls():
-    if getVar('interface') != None:
+    if getVar('interface') is not None:
         getControlPanel().transportButtons.setPlay(False)
         getControlPanel().transportButtons.setRecord(False)
         getVar("presetPanel").presetChoice.setEnable(True)
+        getControlPanel().durationSlider.Enable()
         if getControlPanel().tmpTotalTime != getVar("totalTime"):
             getControlPanel().setTotalTime(getControlPanel().tmpTotalTime, True)
         wx.CallAfter(getControlPanel().vuMeter.reset)
 
 def queryAudioMidiDrivers():
     inputs, inputIndexes, defaultInput, outputs, outputIndexes, defaultOutput, midiInputs, midiInputIndexes, defaultMidiInput = getVar("audioServer").getAvailableAudioMidiDrivers()
-
-    setVar("availableAudioOutputs",  outputs)
-    setVar("availableAudioOutputIndexes",  outputIndexes)
+    setVar("availableAudioOutputs", outputs)
+    setVar("availableAudioOutputIndexes", outputIndexes)
     if getVar("audioOutput") not in outputIndexes:
         try:
             setVar("audioOutput", outputIndexes[outputs.index(defaultOutput)])
@@ -254,8 +302,8 @@ def saveFileDialog(parent, wildcard, type='Save'):
 
     defaultFile = os.path.split(getVar("currentCeciliaFile", unicode=True))[1].split(".")[0]
     saveAsDialog = wx.FileDialog(parent, message="%s file as ..." % type,
-                                 defaultDir=defaultPath, defaultFile=defaultFile+ext,
-                                 wildcard=wildcard, style=wx.SAVE | wx.FD_OVERWRITE_PROMPT)
+                                 defaultDir=defaultPath, defaultFile=defaultFile + ext,
+                                 wildcard=wildcard, style=wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT)
     if saveAsDialog.ShowModal() == wx.ID_OK:
         filePath = ensureNFD(saveAsDialog.GetPath())
         if type == 'Save audio':
@@ -275,44 +323,47 @@ def saveBeforeClose(parent):
                         'Save Changes?', wx.YES_NO | wx.CANCEL | wx.YES_DEFAULT)
     else:
         return True
-    
+
     answer = saveBeforeCloseDialog.ShowModal()
     if answer == wx.ID_YES:
         if saveCeciliaFile(parent, False):
-            result =  True
+            result = True
         else:
-            result =  False
+            result = False
     elif answer == wx.ID_NO:
-        result =  True
+        result = True
     elif answer == wx.ID_CANCEL:
-        result =  False
+        result = False
 
     saveBeforeCloseDialog.Destroy()
     return result
 
 def showErrorDialog(title, msg):
-    dlg = wx.MessageDialog(None, msg, title, wx.OK)
+    if getVar("mainFrame") is not None:
+        dlg = wx.MessageDialog(getVar("mainFrame"), msg, title, wx.OK)
+    else:
+        dlg = wx.MessageDialog(None, msg, title, wx.OK)
     dlg.ShowModal()
     dlg.Destroy()
 
 ###### External app calls ######
 def loadPlayerEditor(app_type):
-    if getVar("systemPlatform")  == 'win32':
-        wildcard =  "Executable files (*.exe)|*.exe|"     \
+    if getVar("systemPlatform") == 'win32':
+        wildcard = "Executable files (*.exe)|*.exe|"     \
                     "All files|*"
-    elif getVar("systemPlatform")  == 'darwin':
-        wildcard =  "Application files (*.app)|*.app|"     \
+    elif getVar("systemPlatform") == 'darwin':
+        wildcard = "Application files (*.app)|*.app|"     \
                     "All files|*"
     else:
         wildcard = "All files|*"
-    
+
     path = ''
     dlg = wx.FileDialog(None, message="Choose a %s..." % app_type,
-                             defaultDir=ensureNFD(os.path.expanduser('~')),
-                             wildcard=wildcard, style=wx.OPEN)
+                        defaultDir=ensureNFD(os.path.expanduser('~')),
+                        wildcard=wildcard, style=wx.FD_OPEN)
 
     if dlg.ShowModal() == wx.ID_OK:
-        path = dlg.GetPath()   
+        path = dlg.GetPath()
     dlg.Destroy()
 
     if path:
@@ -329,20 +380,20 @@ def listenSoundfile(soundfile):
         loadPlayerEditor('soundfile player')
     if os.path.isfile(soundfile):
         app = getVar("soundfilePlayer")
-        if getVar("systemPlatform")  == 'darwin':
+        if getVar("systemPlatform") == 'darwin':
             cmd = 'open -a "%s" "%s"' % (app, soundfile)
             Popen(cmd, shell=True)
-        elif getVar("systemPlatform")  == 'win32':
+        elif getVar("systemPlatform") == 'win32':
             try:
                 Popen([app, soundfile], shell=False)
-            except OSError, OSError2:
-                print 'Unable to open desired software:\n' + app
+            except (OSError, OSError2):
+                print('Unable to open desired software:\n' + app)
         else:
             cmd = '"%s" "%s"' % (app, soundfile)
             try:
                 Popen(cmd, shell=True)
-            except OSError, OSError2:
-                print 'Unable to open desired software:\n' + app
+            except (OSError, OSError2):
+                print('Unable to open desired software:\n' + app)
 
 def editSoundfile(soundfile):
     if getVar("soundfileEditor") == '':
@@ -350,20 +401,20 @@ def editSoundfile(soundfile):
         loadPlayerEditor('soundfile editor')
     if os.path.isfile(soundfile):
         app = getVar("soundfileEditor")
-        if getVar("systemPlatform")  == 'darwin':
-            cmd = 'open -a "%s" "%s"' % (app ,soundfile)
+        if getVar("systemPlatform") == 'darwin':
+            cmd = 'open -a "%s" "%s"' % (app, soundfile)
             Popen(cmd, shell=True)
-        elif getVar("systemPlatform")  == 'win32':
+        elif getVar("systemPlatform") == 'win32':
             try:
                 Popen([app, soundfile], shell=False)
-            except OSError, OSError2:
-                print 'Unable to open desired software:\n' + app
+            except (OSError, OSError2):
+                print('Unable to open desired software:\n' + app)
         else:
             cmd = '%s %s' % (app, soundfile)
             try:
                 Popen(cmd, shell=True)
-            except OSError, OSError2:
-                print 'Unable to open desired software:\n' + app
+            except (OSError, OSError2):
+                print('Unable to open desired software:\n' + app)
 
 def openCurrentFileAsText(curfile):
     if getVar("textEditor") == '':
@@ -371,20 +422,20 @@ def openCurrentFileAsText(curfile):
         loadPlayerEditor('text editor')
     if os.path.isfile(curfile):
         app = getVar("textEditor")
-        if getVar("systemPlatform")  == 'darwin':
+        if getVar("systemPlatform") == 'darwin':
             cmd = 'open -a "%s" "%s"' % (app, os.path.join(os.getcwd(), curfile))
             Popen(cmd, shell=True, cwd=os.path.expanduser("~"))
-        elif getVar("systemPlatform")  == 'win32':
+        elif getVar("systemPlatform") == 'win32':
             try:
                 Popen([app, curfile], shell=False)
-            except OSError, OSError2:
-                print 'Unable to open desired software:\n' + app
+            except (OSError, OSError2):
+                print('Unable to open desired software:\n' + app)
         else:
             cmd = '%s %s' % (app, curfile)
             try:
                 Popen(cmd, shell=True)
-            except OSError, OSError2:
-                print 'Unable to open desired software:\n' + app
+            except (OSError, OSError2):
+                print('Unable to open desired software:\n' + app)
 
 ###### Preset functions ######
 def deletePreset(preset):
@@ -393,7 +444,7 @@ def deletePreset(preset):
 def loadPresetFromDict(preset):
     currentModule = getVar("currentModule")
     setVar("currentModule", None)
-    if getVar("presets").has_key(preset) or preset == "init":
+    if preset in getVar("presets") or preset == "init":
         if preset == "init":
             presetData = getVar("initPreset")
         else:
@@ -450,7 +501,7 @@ def loadPresetFromDict(preset):
                     line.reinit()
                 except:
                     pass
-        elif presetData.has_key('userGraph'):
+        elif 'userGraph' in presetData:
             graphDict = presetData['userGraph']
             ends = ['min', 'max']
             for line in graphDict:
@@ -480,7 +531,7 @@ def loadPresetFromDict(preset):
 ### This is a hack to ensure that plugin knob automations are drawn in the grapher.
 ### Called within a wx.CallAfter to be executed after wx.CallAfter(getControlPanel().setPlugins).
 def againForPluginKnobs(presetData):
-    if presetData.has_key('userGraph'):
+    if 'userGraph' in presetData:
         graphDict = presetData['userGraph']
         for line in graphDict:
             for i, graphLine in enumerate(getVar("grapher").getPlotter().getData()):
@@ -508,8 +559,8 @@ def savePresetToDict(presetName):
         widgetDict = dict()
         plugins = getVar("plugins")
         for i, plugin in enumerate(plugins):
-            if plugin == None:
-                widgetDict[i] = ['None', [0,0,0,0],[[0,0,None],[0,0,None],[0,0,None]]]
+            if plugin is None:
+                widgetDict[i] = ['None', [0, 0, 0, 0], [[0, 0, None], [0, 0, None], [0, 0, None]]]
             else:
                 widgetDict[i] = [plugin.getName(), plugin.getParams(), plugin.getStates()]
         presetDict['plugins'] = copy.deepcopy(widgetDict)
@@ -523,7 +574,7 @@ def savePresetToDict(presetName):
 
         graphDict = dict()
         for line in getVar("grapher").getPlotter().getData():
-            if line.slider == None:
+            if line.slider is None:
                 graphDict[line.getName()] = line.getLineState()
             else:
                 outvalue = line.slider.getValue()
@@ -533,12 +584,12 @@ def savePresetToDict(presetName):
                     ends = ['min', 'max']
                     for i in range(len(outvalue)):
                         if line.getLabel().endswith(ends[i]):
-                            graphDict[line.getName()+ends[i]] = line.getLineState()
+                            graphDict[line.getName() + ends[i]] = line.getLineState()
                             break
                 elif line.slider.widget_type == "splitter":
                     for i in range(len(outvalue)):
                         if line.getLabel().endswith("%d" % i):
-                            graphDict[line.getName()+"_%d" % i] = line.getLineState()
+                            graphDict[line.getName() + "_%d" % i] = line.getLineState()
                             break
         presetDict['userGraph'] = copy.deepcopy(graphDict)
         del graphDict
@@ -554,7 +605,7 @@ def completeUserInputsDict():
         getVar("userInputs")[i]['mode'] = 0
         if getVar("userInputs")[i]['type'] == 'csampler':
             cfilein = getControlPanel().getCfileinFromName(i)
-            getVar("userInputs")[i]['off'+cfilein.getName()] = cfilein.getOffset()
+            getVar("userInputs")[i]['off' + cfilein.getName()] = cfilein.getOffset()
             getVar("userInputs")[i]['loopMode'] = cfilein.getSamplerInfo()['loopMode']
             getVar("userInputs")[i]['startFromLoop'] = cfilein.getSamplerInfo()['startFromLoop']
             getVar("userInputs")[i]['loopX'] = cfilein.getSamplerInfo()['loopX']
@@ -564,7 +615,7 @@ def completeUserInputsDict():
             getVar("userInputs")[i]['transp'] = cfilein.getSamplerInfo()['transp']
         elif getVar("userInputs")[i]['type'] == 'cfilein':
             cfilein = getControlPanel().getCfileinFromName(i)
-            getVar("userInputs")[i]['off'+cfilein.getName()] = cfilein.getOffset()
+            getVar("userInputs")[i]['off' + cfilein.getName()] = cfilein.getOffset()
     return copy.deepcopy(getVar("userInputs"))
 
 def updateInputsFromDict():
@@ -588,12 +639,24 @@ def updateInputsFromDict():
                     cfilein.getSamplerFrame().setTransp(inputDict[k])
                 elif k == 'startFromLoop':
                     cfilein.getSamplerFrame().setStartFromLoop(inputDict[k])
-                elif k == ('off'+input):
+                elif k == ('off' + input):
                     cfilein.setOffset(inputDict[k])
                 elif k == 'path':
                     pass
 
 ###### Open / Save / Close ######
+def saveCompileBackupFile(cecFilePath):
+    with open(cecFilePath, "r") as f:
+        _module = f.read()
+    with open(MODULE_COMPILE_BACKUP_PATH, "w") as f:
+        f.write(_module)
+
+def saveRuntimeBackupFile(cecFilePath):
+    with open(cecFilePath, "r") as f:
+        _module = f.read()
+    with open(MODULE_RUNTIME_BACKUP_PATH, "w") as f:
+        f.write(_module)
+
 def saveCeciliaFile(parent, showDialog=True):
     if getVar("builtinModule") or showDialog:
         wildcard = "Cecilia file (*.%s)|*.%s" % (FILE_EXTENSION, FILE_EXTENSION)
@@ -620,7 +683,7 @@ def saveCeciliaFile(parent, showDialog=True):
     except IOError:
         dlg = wx.MessageDialog(parent, 'Please verify permissions and write access on the file and try again.',
                             '"%s" could not be opened for writing' % (fileToSave), wx.OK | wx.ICON_EXCLAMATION)
-        if dlg.ShowModal()==wx.ID_OK:
+        if dlg.ShowModal() == wx.ID_OK:
             dlg.Destroy()
             return
 
@@ -634,19 +697,21 @@ def saveCeciliaFile(parent, showDialog=True):
     file.write(preset)
 
     file.close()
-    
+
     setVar("builtinModule", False)
     setVar("currentCeciliaFile", fileToSave)
     setVar("isModified", False)
-    
+
+    saveCompileBackupFile(fileToSave)
+
     return True
 
 def openCeciliaFile(parent, openfile=None, builtin=False):
     if not openfile:
         wildcard = "Cecilia file (*.%s)|*.%s" % (FILE_EXTENSION, FILE_EXTENSION)
         defaultPath = getVar("openFilePath", unicode=True)
-        openDialog = wx.FileDialog(parent, message='Choose a Cecilia file to open...', 
-                                    defaultDir=defaultPath, wildcard=wildcard, style=wx.OPEN)
+        openDialog = wx.FileDialog(parent, message='Choose a Cecilia file to open...',
+                                    defaultDir=defaultPath, wildcard=wildcard, style=wx.FD_OPEN)
         if openDialog.ShowModal() == wx.ID_OK:
             cecFilePath = openDialog.GetPath()
             setVar("openFilePath", (os.path.split(cecFilePath)[0]))
@@ -654,9 +719,8 @@ def openCeciliaFile(parent, openfile=None, builtin=False):
             cecFilePath = None
         openDialog.Destroy()
 
-        if cecFilePath == None:
+        if cecFilePath is None:
             return
-
     else:
         cecFilePath = openfile
 
@@ -667,9 +731,9 @@ def openCeciliaFile(parent, openfile=None, builtin=False):
     if getVar("rememberedSound") and getVar("interfaceWidgets") and getVar("userInputs"):
         names = [d['name'] for d in getVar("interfaceWidgets")]
         keys = getVar("userInputs").keys()
-        sortlist = zip([names.index(k) for k in keys], keys)
+        sortlist = list(zip([names.index(k) for k in keys], keys))
         sortlist.sort()
-        index, keys = zip(*sortlist)
+        index, keys = list(zip(*sortlist))
         for key in keys:
             if getVar("userInputs")[key]['path'] != '':
                 snds.append(getVar("userInputs")[key]['path'])
@@ -679,15 +743,19 @@ def openCeciliaFile(parent, openfile=None, builtin=False):
 
     getVar("mainFrame").Hide()
 
-    setVar("builtinModule", builtin)
-    setVar("currentCeciliaFile", cecFilePath)
-    parent.newRecent(cecFilePath)
-
-    moduleInfo = ''
-
     setVar("isModified", False)
 
-    getVar("audioServer").openCecFile(cecFilePath)
+    if not getVar("audioServer").openCecFile(cecFilePath):
+        return
+
+    setVar("builtinModule", builtin)
+    setVar("currentCeciliaFile", cecFilePath)
+    setVar("lastCeciliaFile", cecFilePath)
+
+    if parent is not None:
+        parent.newRecent(cecFilePath)
+
+    saveCompileBackupFile(cecFilePath)
 
     if getVar("interface"):
         for i, cfilein in enumerate(getControlPanel().getCfileinList()):
@@ -697,8 +765,10 @@ def openCeciliaFile(parent, openfile=None, builtin=False):
 
     savePresetToDict("init")
 
-    if getVar("presets").has_key("last save"):
-        loadPresetFromDict("last save")
+    if "last save" in getVar("presets"):
+        setVar("presetToLoad", "last save")
+
+    getVar("mainFrame").updateTitle()
 
     wx.CallAfter(getVar("interface").Raise)
 
@@ -707,10 +777,6 @@ def closeCeciliaFile(parent):
         return False
     getVar("mainFrame").closeInterface()
     setVar("currentCeciliaFile", '')
-    if getVar("interface"):
-        getVar("interface").onClose(wx.EVT_CLOSE)
-        setVar("interface", None)
-        setVar("presets", {})
     wx.CallLater(200, setVar, "isModified", False)
     return True
 
@@ -724,7 +790,8 @@ def resetWidgetVariables():
     setVar("samplerSliders", [])
     setVar("grapher", None)
     setVar("presetPanel", None)
-   
+    setVar("tooltips", [])
+
 def parseInterfaceText():
     interfaceWidgets = getVar("interfaceWidgets")
     return interfaceWidgets
@@ -735,82 +802,41 @@ def updateNchnlsDevices():
     except:
         pass
 
-###### Interpolation functions ######
-def interpolate(lines, size, listlen):
-   scale = size / lines[-1][0]
-   templist = []
-   for i in range(listlen-1):
-       t = lines[i+1][0] - lines[i][0]
-       num = int(round(t * scale))
-       if num == 0:
-           pass
-       else:
-           step = (lines[i+1][1] - lines[i][1]) / num
-           for j in range(num):
-               templist.append(lines[i][1] + (step*j))
-   return templist               
+###### Conversion functions #######
+def interpFloat(t, v1, v2):
+    "interpolator for a single value; interprets t in [0-1] between v1 and v2"
+    return (v2 - v1) * t + v1
 
-def interpolateCurved(lines, size, listlen):
-    lines = removeDuplicates(lines)
-    scale = size / float(len(lines))
-    depth = int(round(scale))
-    off = int(1. / (scale - depth))
-    templist = []
-    for i in range(len(lines)-1):
-        num = depth
-        if (i%off) == 0: num = depth + 1
-        step = (lines[i+1][1] - lines[i][1]) / num
-        for j in range(num):
-            templist.append(lines[i][1] + (step*j))
-    return templist
+def tFromValue(value, v1, v2):
+    "returns a t (in range 0-1) given a value in the range v1 to v2"
+    return (value - v1) / (v2 - v1)
 
-def interpolateLog(lines, size, listlen, yrange):
-    scale = size / lines[-1][0]
-    templist = []
-    for i in range(listlen-1):
-        t = lines[i+1][0] - lines[i][0]
-        num = int(round(t * scale))
-        if num == 0:
-            pass
-        else:
-            step = (lines[i+1][1] - lines[i][1]) / num
-            for j in range(num):
-                templist.append(lines[i][1] + (step*j))
-    list = []
-    if yrange[0] == 0: yoffrange = .00001
-    else: yoffrange = yrange[0] 
-    totalRange = yrange[1] - yoffrange
-    currentTotalRange = math.log10(yrange[1]/yrange[0])
-    currentMin = math.log10(yrange[0])
-    for p in templist:
-        if p == 0: p = .00001
-        ratio = (p - yoffrange) / totalRange
-        list.append(math.pow(10, ratio * currentTotalRange + currentMin))
-    return list
+def clamp(v, minv, maxv):
+    "clamps a value within a range"
+    if v < minv: v = minv
+    if v > maxv: v = maxv
+    return v
+
+def toLog(t, v1, v2):
+    v1 = float(v1)
+    return math.log10(t / v1) / math.log10(v2 / v1)
+
+def toExp(t, v1, v2):
+    return math.pow(10, t * (math.log10(v2) - math.log10(v1)) + math.log10(v1))
 
 ###### Utility functions #######
-def removeDuplicates(seq):
-   result = []
-   for item in seq:
-       if item not in result:
-           result.append(item)
-   return result
-
 def autoRename(path, index=0, wrap=False):
     if os.path.exists(path):
         file = ensureNFD(os.path.split(path)[1])
         if wrap:
             name = ensureNFD(file.rsplit('.', 1)[0])[:-4]
-        else:    
+        else:
             name = ensureNFD(file.rsplit('.', 1)[0])
         ext = file.rsplit('.', 1)[1]
 
         if len(name) >= 5:
-            try:
-                if name[-4] == '_' and type(eval(name[-3:])) == IntType:
-                    name = name[:-4]
-            except:
-                pass
+            if name[-4] == '_' and name[-3:].isdigit():
+                name = name[:-4]
         root = os.path.split(path)[0]
         filelist = os.listdir(root)
         num = index
@@ -818,26 +844,26 @@ def autoRename(path, index=0, wrap=False):
             f = ensureNFD(f)
             if name in f and ext in f:
                 num += 1
-        newName = name + '_%03d' % num + '.' + ext      
+        newName = name + '_%03d' % num + '.' + ext
         newPath = os.path.join(root, newName)
-        return autoRename(newPath, index+1, True)
+        return autoRename(newPath, index + 1, True)
     else:
         newPath = path
     return newPath
 
-def shortenName(name,maxChar):
+def shortenName(name, maxChar):
     name = ensureNFD(name)
-    if len(name)>maxChar:
+    if len(name) > maxChar:
         shortenChar = '...'
         addSpace = 0
-        charSpace = (maxChar-len(shortenChar)) / 2
-        if (maxChar-5) % 2 != 0:
+        charSpace = (maxChar - len(shortenChar)) // 2
+        if (maxChar - 5) % 2 != 0:
             addSpace = 1
-        name = name[:charSpace+addSpace] + shortenChar + name[len(name)-charSpace:]
+        name = name[:charSpace + addSpace] + shortenChar + name[len(name) - charSpace:]
     return name
 
 def ensureNFD(unistr):
-    if getVar("systemPlatform") in ['linux2', 'win32']:
+    if getVar("systemPlatform").startswith('linux') or sys.platform == 'win32':
         encodings = [DEFAULT_ENCODING, ENCODING,
                      'cp1252', 'iso-8859-1', 'utf-16']
         format = 'NFC'
@@ -846,7 +872,7 @@ def ensureNFD(unistr):
                      'macroman', 'iso-8859-1', 'utf-16']
         format = 'NFC'
     decstr = unistr
-    if type(decstr) != UnicodeType:
+    if type(decstr) != unicode_t:
         for encoding in encodings:
             try:
                 decstr = decstr.decode(encoding)
@@ -855,19 +881,9 @@ def ensureNFD(unistr):
                 continue
             except:
                 decstr = "UnableToDecodeString"
-                print "Unicode encoding not in a recognized format..."
+                print("Unicode encoding not in a recognized format...")
                 break
     if decstr == "UnableToDecodeString":
         return unistr
     else:
         return unicodedata.normalize(format, decstr)
-
-def toSysEncoding(unistr):
-    try:
-        if getVar("systemPlatform") == "win32":
-            unistr = unistr.encode(ENCODING)
-        else:
-            unistr = unicode(unistr)
-    except:
-        pass
-    return unistr
