@@ -18,18 +18,18 @@ You should have received a copy of the GNU General Public License
 along with Cecilia 5.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import wx
 import os, time, random
-from constants import *
-import CeciliaLib
-import PreferencePanel 
-from menubar import InterfaceMenuBar
-import CeciliaInterface
-from Widgets import *
-from DocFrame import ManualFrame
+import wx
+from .constants import *
+import Resources.CeciliaLib as CeciliaLib
+import Resources.PreferencePanel as PreferencePanel
+import Resources.CeciliaInterface as CeciliaInterface
+from .menubar import InterfaceMenuBar
+from .Widgets import *
+from .DocFrame import ManualFrame
 
 class CeciliaMainFrame(wx.Frame):
-    def __init__(self, parent, ID):        
+    def __init__(self, parent, ID):
         wx.Frame.__init__(self, parent, ID)
         self.menubar = InterfaceMenuBar(self, self)
         self.SetMenuBar(self.menubar)
@@ -39,20 +39,15 @@ class CeciliaMainFrame(wx.Frame):
         self.api_doc_frame = ManualFrame(kind="api")
         self.mod_doc_frame = ManualFrame(kind="modules")
 
-    def setTime(self,curTime=0):
+    def setTime(self, curTime=0):
         self.time = curTime
 
     def updateTitle(self, isModified=False):
-        if CeciliaLib.getVar("builtinModule"):
-            file = os.path.split(CeciliaLib.getVar("currentCeciliaFile", unicode=True))[1]
-        else:
-            file = CeciliaLib.getVar("currentCeciliaFile", unicode=True)
-        title = os.path.split(CeciliaLib.getVar("currentCeciliaFile", unicode=True))[1]  
-        if not isModified:
-            if CeciliaLib.getVar("interface"):
+        title = os.path.split(CeciliaLib.getVar("currentCeciliaFile", unicode=True))[1]
+        if CeciliaLib.getVar("interface"):
+            if not isModified:
                 CeciliaLib.getVar("interface").updateTitle('Interface - ' + title)
-        else:
-            if CeciliaLib.getVar("interface"):
+            else:
                 CeciliaLib.getVar("interface").updateTitle('*** Interface - ' + title + ' ***')
 
     def onShortPlayStop(self, event):
@@ -78,14 +73,14 @@ class CeciliaMainFrame(wx.Frame):
     def applyBatchProcessingFolder(self, value):
         folderName = value
         if folderName == "":
-            return 
+            return
         old_file_type = CeciliaLib.getVar("audioFileType")
         cfileins = CeciliaLib.getControlPanel().getCfileinList()
         num_snds = len(cfileins[0].fileMenu.choice)
-        dlg = wx.ProgressDialog("Batch processing on sound folder", "", maximum = num_snds, parent=self,
-                               style = wx.PD_APP_MODAL | wx.PD_AUTO_HIDE | wx.PD_SMOOTH)
-        dlg.SetMinSize((600,-1))
-        dlg.SetClientSize((600,100))
+        dlg = wx.ProgressDialog("Batch processing on sound folder", "", maximum=num_snds, parent=self,
+                               style=wx.PD_APP_MODAL | wx.PD_AUTO_HIDE | wx.PD_SMOOTH)
+        dlg.SetMinSize((600, -1))
+        dlg.SetClientSize((600, 100))
         count = 0
         totaltime = CeciliaLib.getVar("totalTime")
         for snd in cfileins[0].fileMenu.choice:
@@ -135,18 +130,22 @@ class CeciliaMainFrame(wx.Frame):
         if "last save" in presets:
             presets.remove("last save")
         num_presets = len(presets)
-        dlg = wx.ProgressDialog("Batch processing on preset sequence", "", maximum = num_presets, parent=self,
-                               style = wx.PD_APP_MODAL | wx.PD_AUTO_HIDE | wx.PD_SMOOTH)
-        dlg.SetMinSize((600,-1))
-        dlg.SetClientSize((600,100))
+        dlg = wx.ProgressDialog("Batch processing on preset sequence",
+                                "", maximum=num_presets, parent=self,
+                                style=wx.PD_APP_MODAL | wx.PD_AUTO_HIDE | wx.PD_SMOOTH)
+        dlg.SetMinSize((600, -1))
+        dlg.SetClientSize((600, 100))
+        if len(cfileins) > 0:
+            filepath = cfileins[0].filePath
         count = 0
         for preset in presets:
             CeciliaLib.loadPresetFromDict(preset)
             if len(cfileins) == 0:
                 path = os.path.join(os.path.expanduser("~"), "Desktop")
                 name = "batch"
-                ext = "."+CeciliaLib.getVar("audioFileType")
+                ext = "." + CeciliaLib.getVar("audioFileType")
             else:
+                cfileins[0].onLoadFile(filepath)
                 path, fname = os.path.split(cfileins[0].filePath)
                 name, ext = os.path.splitext(fname)
             if not os.path.isdir(os.path.join(path, folderName)):
@@ -161,30 +160,32 @@ class CeciliaMainFrame(wx.Frame):
 
     def onBatchProcessing(self, event):
         if event.GetId() == ID_BATCH_FOLDER:
-            f = BatchPopupFrame(self, self.applyBatchProcessingFolder) 
+            f = BatchPopupFrame(self, self.applyBatchProcessingFolder)
         else:
-            f = BatchPopupFrame(self, self.applyBatchProcessingPreset) 
-        f.MakeModal(True)
+            f = BatchPopupFrame(self, self.applyBatchProcessingPreset)
         f.CenterOnScreen()
         f.Show()
 
     def onUseSoundDuration(self, evt):
         CeciliaLib.setVar("useSoundDur", evt.GetInt())
 
-    def onSelectOutputFilename(self):        
+    def onSelectOutputFilename(self):
         file = CeciliaLib.saveFileDialog(self, AUDIO_FILE_WILDCARD, type='Save audio')
-        if file != None:
+        if file is not None:
             CeciliaLib.setVar("saveAudioFilePath", os.path.split(file)[0])
         return file
 
     def closeInterface(self):
-        if CeciliaLib.getVar("interface"):
+        if CeciliaLib.getVar("interface") is not None:
             CeciliaLib.getVar("interface").onClose(None)
             CeciliaLib.setVar("interface", None)
 
     def newRecent(self, file, remove=False):
+        if ".cecilia5" in file:
+            return
+
         file = CeciliaLib.ensureNFD(file)
-        filename = os.path.join(TMP_PATH,'.recent.txt')
+        filename = os.path.join(TMP_PATH, '.recent.txt')
         try:
             f = open(filename, "r")
             lines = [CeciliaLib.ensureNFD(line[:-1]) for line in f.readlines()]
@@ -194,7 +195,7 @@ class CeciliaMainFrame(wx.Frame):
 
         update = False
         if not remove:
-            if not file in lines and not 'Resources/modules/' in file:
+            if file not in lines and 'Resources/modules/' not in file:
                 lines.insert(0, file)
                 update = True
         else:
@@ -215,10 +216,10 @@ class CeciliaMainFrame(wx.Frame):
         f = open(filename, "r")
         for line in f.readlines():
             recentFiles.append(line)
-        f.close()    
+        f.close()
         if recentFiles:
             for item in self.menubar.openRecentMenu.GetMenuItems():
-                self.menubar.openRecentMenu.DeleteItem(item)
+                self.menubar.openRecentMenu.Delete(item)
             for file in recentFiles:
                 try:
                     self.menubar.openRecentMenu.Append(subId2, file)
@@ -231,7 +232,6 @@ class CeciliaMainFrame(wx.Frame):
             CeciliaLib.openCeciliaFile(self)
         elif os.path.isfile(event):
             CeciliaLib.openCeciliaFile(self, event, builtin)
-        self.updateTitle()
 
     def onOpenRandom(self, event):
         categories = [folder for folder in os.listdir(MODULES_PATH) if not folder.startswith(".")]
@@ -243,14 +243,13 @@ class CeciliaMainFrame(wx.Frame):
     def openRecent(self, event):
         menu = self.GetMenuBar()
         id = event.GetId()
-        file = menu.FindItemById(id).GetLabel()
-        if os.path.isfile(file[:-1]):
-            CeciliaLib.openCeciliaFile(self, file[:-1])
-            self.updateTitle()
+        file = menu.FindItemById(id).GetLabel().replace("\n", "").strip()
+        if os.path.isfile(file):
+            CeciliaLib.openCeciliaFile(self, file)
         else:
             CeciliaLib.showErrorDialog("Error while trying to open a file!", "No such file : %s" % file[:-1])
-            self.newRecent(file[:-1], remove=True)
-        
+            self.newRecent(file, remove=True)
+
     def onOpenBuiltin(self, event):
         menu = self.GetMenuBar()
         id = event.GetId()
@@ -263,7 +262,6 @@ class CeciliaMainFrame(wx.Frame):
                 break
         name = os.path.join(CeciliaLib.ensureNFD(MODULES_PATH), dirname, filename)
         CeciliaLib.openCeciliaFile(self, name, True)
-        self.updateTitle()
 
     def onOpenPrefModule(self, event):
         menu = self.GetMenuBar()
@@ -278,14 +276,12 @@ class CeciliaMainFrame(wx.Frame):
         if dirname:
             name = os.path.join(dirname, filename)
             CeciliaLib.openCeciliaFile(self, name)
-            self.updateTitle()
 
     def openModuleAsText(self, event):
         CeciliaLib.openCurrentFileAsText(CeciliaLib.getVar("currentCeciliaFile"))
-        
+
     def reloadCurrentModule(self, event):
         CeciliaLib.openCeciliaFile(self, CeciliaLib.getVar("currentCeciliaFile"))
-        self.updateTitle()
 
     def onSave(self, event):
         CeciliaLib.saveCeciliaFile(self, showDialog=False)
@@ -309,7 +305,7 @@ class CeciliaMainFrame(wx.Frame):
             CeciliaLib.setVar("rememberedSound", False)
 
     def onUpdateInterface(self, event):
-        if event != None:
+        if event is not None:
             snds = []
             if CeciliaLib.getVar("rememberedSound"):
                 for key in CeciliaLib.getVar("userInputs").keys():
@@ -326,7 +322,7 @@ class CeciliaMainFrame(wx.Frame):
         CeciliaLib.setVar("interface", ceciliaInterface)
         if CeciliaLib.getVar("presets") != {}:
             CeciliaLib.getVar("presetPanel").loadPresets()
-        if event != None:
+        if event is not None:
             for i, cfilein in enumerate(CeciliaLib.getControlPanel().getCfileinList()):
                 if i >= len(snds):
                     break
@@ -337,8 +333,28 @@ class CeciliaMainFrame(wx.Frame):
             CeciliaLib.setVar('showSpectrum', 1)
         else:
             CeciliaLib.setVar('showSpectrum', 0)
-            
+
+    def openSpectrumWindow(self):
+        if CeciliaLib.getVar('spectrumFrame') is None:
+            f = SpectrumFrame(CeciliaLib.getVar("interface"))
+            f.setAnalyzer(CeciliaLib.getVar("audioServer").spectrum)
+            f.Center()
+            f.Show()
+            CeciliaLib.setVar('spectrumFrame', f)
+
     def onQuit(self, event):
+        ok = True
+        msg = "Do you want to save the current state of the module?"
+        dlg = wx.MessageDialog(self, msg, "Quit Cecilia5...", style=wx.YES_NO | wx.CANCEL | wx.STAY_ON_TOP)
+        ret = dlg.ShowModal()
+        if ret == wx.ID_YES:
+            CeciliaLib.saveCeciliaFile(self, showDialog=False)
+        elif ret == wx.ID_CANCEL:
+            ok = False
+        dlg.Destroy()
+        if not ok:
+            return
+
         if not CeciliaLib.closeCeciliaFile(self):
             return
         try:
@@ -348,7 +364,7 @@ class CeciliaMainFrame(wx.Frame):
         if CeciliaLib.getVar("audioServer").isAudioServerRunning():
             CeciliaLib.getVar("audioServer").stop()
             time.sleep(.2)
-        if CeciliaLib.getVar('spectrumFrame') != None:
+        if CeciliaLib.getVar('spectrumFrame') is not None:
             try:
                 CeciliaLib.getVar('spectrumFrame')._destroy(None)
             except:
@@ -366,7 +382,7 @@ class CeciliaMainFrame(wx.Frame):
 
     def onHelpAbout(self, evt):
         Y = CeciliaLib.getVar("displaySize")[0][1]
-        about = AboutPopupFrame(self, Y/5)
+        about = AboutPopupFrame(self, Y // 5)
         about.Show()
 
     def onModuleAbout(self, evt):
@@ -377,3 +393,8 @@ class CeciliaMainFrame(wx.Frame):
     def onDocFrame(self, evt):
         self.api_doc_frame.Center()
         self.api_doc_frame.Show()
+
+    def onGraphFrame(self, evt):
+        self.graph_doc_frame = wx.MessageDialog(self, TT_GRAPHER)
+        self.graph_doc_frame.ShowModal()
+        self.graph_doc_frame.Destroy()
