@@ -19,7 +19,14 @@ along with Cecilia 5.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 import sys, os
-from constants import *
+import unicodedata
+from .constants import *
+from pyo import pa_get_default_devices_from_host
+
+if sys.version_info[0] < 3:
+    unicode_t = unicode
+else:
+    unicode_t = str
 
 CeciliaVar = dict()
 
@@ -34,6 +41,7 @@ CeciliaVar['mainFrame'] = None
 
 # Path of the currently opened file
 CeciliaVar['currentCeciliaFile'] = ''
+CeciliaVar['lastCeciliaFile'] = ''
 CeciliaVar['builtinModule'] = False
 CeciliaVar['currentModuleRef'] = None
 CeciliaVar['currentModule'] = None
@@ -47,6 +55,7 @@ CeciliaVar['grapherLinePath'] = os.path.expanduser('~')
 
 # Boolean that says if file was modified since last save
 CeciliaVar['isModified'] = False
+CeciliaVar['presetToLoad'] = None
 
 # Audio / Midi
 CeciliaVar['availableAudioOutputs'] = []
@@ -86,6 +95,8 @@ CeciliaVar['presets'] = dict()
 CeciliaVar['initPreset'] = None
 CeciliaVar['presetPanel'] = None
 
+CeciliaVar['tooltips'] = []
+
 # Performance variables
 CeciliaVar['toDac'] = True
 CeciliaVar['outputFile'] = ''
@@ -98,6 +109,17 @@ CeciliaVar['automaticMidiBinding'] = 0
 CeciliaVar['showSpectrum'] = 0
 CeciliaVar['spectrumFrame'] = None
 
+if sys.platform.startswith("win"):
+    def_in, def_out = pa_get_default_devices_from_host("wasapi")
+elif sys.platform.startswith("darwin"):
+    def_in, def_out = pa_get_default_devices_from_host("core")
+else:
+    def_in, def_out = pa_get_default_devices_from_host("alsa")
+if def_in < 0:
+    def_in = 0
+if def_out < 0:
+    def_out = 0
+
 # Server Flags
 CeciliaVar['sr'] = 44100
 CeciliaVar['nchnls'] = 2
@@ -107,8 +129,8 @@ CeciliaVar['audioFileType'] = 'aif' # aif, wav, flac, ogg, sd2, au, caf
 CeciliaVar['samplePrecision'] = '32 bit' # '32 bit', '64 bit'
 CeciliaVar['bufferSize'] = '512'
 CeciliaVar['audioHostAPI'] = 'portaudio'
-CeciliaVar['audioOutput'] = 0
-CeciliaVar['audioInput'] = 0
+CeciliaVar['audioOutput'] = def_out
+CeciliaVar['audioInput'] = def_in
 CeciliaVar['enableAudioInput'] = 0
 CeciliaVar['useMidi'] = 0
 CeciliaVar['useSoundDur'] = 0
@@ -120,86 +142,121 @@ CeciliaVar['jack'] = {'client': 'cecilia5'}
 
 CeciliaVar['lastAudioFiles'] = ""
 
+def ensureNFD(unistr):
+    if sys.platform.startswith('linux') or sys.platform == 'win32':
+        encodings = [DEFAULT_ENCODING, ENCODING,
+                     'cp1252', 'iso-8859-1', 'utf-16']
+        format = 'NFC'
+    else:
+        encodings = [DEFAULT_ENCODING, ENCODING,
+                     'macroman', 'iso-8859-1', 'utf-16']
+        format = 'NFC'
+    decstr = unistr
+    if type(decstr) != unicode_t:
+        for encoding in encodings:
+            try:
+                decstr = decstr.decode(encoding)
+                break
+            except UnicodeDecodeError:
+                continue
+            except:
+                decstr = "UnableToDecodeString"
+                print("Unicode encoding not in a recognized format...")
+                break
+    if decstr == "UnableToDecodeString":
+        return unistr
+    else:
+        return unicodedata.normalize(format, decstr)
+
+# Reading and writing of preferences should be moved to CeciliaLib.
 def readCeciliaPrefsFromFile():
     if os.path.isfile(PREFERENCES_FILE):
         try:
-            file = open(PREFERENCES_FILE, 'rt')
-        except IOError:
+            file = open(PREFERENCES_FILE, 'rt', encoding=FILE_ENCODING)
+        except:
             print('Unable to open the preferences file.\n')
+            print('Cecilia will use the default preferences.\n')
             return
-        
+
         print('Loading Cecilia Preferences...')
-        
+
         #### Some special cases ####
         convertToInt = ['sr', 'defaultNchnls', 'audioOutput', 'audioInput', 'sampSize', 'automaticMidiBinding',
                         'midiDeviceIn', 'useTooltips', 'enableAudioInput', 'graphTexture', 'showSpectrum', 'useSoundDur',
-                        'defaultFirstInput', 'defaultFirstOutput']  
-        convertToFloat = ['defaultTotalTime', 'globalFade', 'DEBUG']                      
+                        'defaultFirstInput', 'defaultFirstOutput']
+        convertToFloat = ['defaultTotalTime', 'globalFade', 'DEBUG']
         convertToTuple = ['interfaceSize', 'interfacePosition']
         jackPrefs = ['client']
-        
-        # Go thru the text file to assign values to the variables
-        for i, line in enumerate(file.readlines()):
-            if i == 0:
-                if not line.startswith("version"):
-                    print('preferences file from an older version not used. New preferences will be created.\n')
-                    return
-                else:
-                    if line.strip(' \n').split('=')[1] != APP_VERSION:
+
+        text = ensureNFD(file.read())
+
+        # Go through the text file to assign values to the variables
+        try:
+            for i, line in enumerate(text.splitlines()):
+                if i == 0:
+                    if not line.startswith("version"):
                         print('preferences file from an older version not used. New preferences will be created.\n')
                         return
                     else:
-                        continue
+                        if line.strip(' \n').split('=')[1] != APP_VERSION:
+                            print('preferences file from an older version not used. New preferences will be created.\n')
+                            return
+                        else:
+                            continue
 
-            pref = line.strip(' \n').split('=')
-            
-            if pref[1]!='':
-                if pref[0] in convertToInt:
-                    CeciliaVar[pref[0]] = int(pref[1])
-                elif pref[0] in convertToFloat:
-                    CeciliaVar[pref[0]] = float(pref[1])
-                elif pref[0] in convertToTuple:
-                    CeciliaVar[pref[0]] = eval(pref[1])
-                elif pref[0] in jackPrefs:
-                    CeciliaVar['jack'][pref[0]] = pref[1]
-                else:
-                    if pref[0] == 'audioHostAPI' and pref[1] not in AUDIO_DRIVERS:
-                        CeciliaVar[pref[0]] = 'portaudio'
+                pref = line.strip(' \n').split('=')
+
+                if pref[1] != '':
+                    if pref[0] in convertToInt:
+                        CeciliaVar[pref[0]] = int(pref[1])
+                    elif pref[0] in convertToFloat:
+                        CeciliaVar[pref[0]] = float(pref[1])
+                    elif pref[0] in convertToTuple:
+                        CeciliaVar[pref[0]] = eval(pref[1])
+                    elif pref[0] in jackPrefs:
+                        CeciliaVar['jack'][pref[0]] = pref[1]
                     else:
-                        CeciliaVar[pref[0]] = pref[1]
+                        if pref[0] == 'audioHostAPI' and pref[1] not in AUDIO_DRIVERS:
+                            CeciliaVar[pref[0]] = 'portaudio'
+                        else:
+                            CeciliaVar[pref[0]] = pref[1]
+        except:
+            print("something wrong happened when reading preferences "
+                   "(probably character encoding/decoding problem), "
+                   "some preferences may be lost.")
+
         file.close()
         CeciliaVar["nchnls"] = CeciliaVar["defaultNchnls"]
-        
+
     else:
         print('Preferences file not found. Using defaults...\n')
 
 def writeCeciliaPrefsToFile():
     varsToSave = ['interfaceSize', 'interfacePosition', 'useTooltips', 'enableAudioInput', 'textEditor',
                   'sr', 'defaultNchnls', 'sampSize', 'audioHostAPI', 'audioFileType', 'audioOutput',
-                  'audioInput', 'midiPort', 'midiDeviceIn', 'samplePrecision', 'client', 'graphTexture', 
+                  'audioInput', 'midiPort', 'midiDeviceIn', 'samplePrecision', 'client', 'graphTexture',
                   'globalFade', 'bufferSize', 'soundfilePlayer', 'soundfileEditor', 'prefferedPath', 'DEBUG',
                   'openFilePath', 'saveFilePath', 'saveAudioFilePath', 'openAudioFilePath', 'grapherLinePath',
                   'defaultTotalTime', 'lastAudioFiles', 'automaticMidiBinding', 'showSpectrum', 'useSoundDur',
-                  'defaultFirstInput', 'defaultFirstOutput']
-    
+                  'defaultFirstInput', 'defaultFirstOutput', 'lastCeciliaFile']
+
     print('Writing Cecilia preferences...')
-    
+
     try:
-        file = open(PREFERENCES_FILE,'wt')
+        file = open(PREFERENCES_FILE, 'wt')
     except IOError:
         print('Unable to open the preferences file.\n')
         return
-    
+
     file.write("version=%s\n" % APP_VERSION)
     for key in CeciliaVar:
         if key in varsToSave:
             line = '%s=%s\n' % (key, CeciliaVar[key])
             file.write(line)
-        elif key=='jack':
+        elif key == 'jack':
             line = '%s=%s\n' % ('client', CeciliaVar[key]['client'])
             file.write(line)
-    
+
     file.close()
 
 readCeciliaPrefsFromFile()
-    
